pub type ValidatorGroups<T> = StorageValue<_GeneratedPrefixForStorageValidatorGroups<T>, Vec<Vec<ValidatorIndex>>, ValueQuery>;Expand description
All the validator groups. One for each core. Indices are into ActiveValidators - not the
broader set of Polkadot validators, but instead just the subset used for parachains during
this session.
Bound: The number of cores is the sum of the numbers of parachains and parathread multiplexers. Reasonably, 100-1000. The dominant factor is the number of validators: safe upper bound at 10k.
Storage type is [StorageValue] with value type Vec < Vec < ValidatorIndex > >.
Aliased Type
pub struct ValidatorGroups<T>(/* private fields */);